@@ -266,6 +266,22 @@ class mute_on_join():
             await db.close()
         except:
             await db.close()
+
+    async def manual_unmute_check(after, roleid, dir):
+        os.chdir(dir)
+        if after.bot:
+            return
+        guildid = str(after.guild.id)
+        role = after.guild.get_role(roleid)
+        db = await aiosqlite.connect("muted.db")
+        memberid = str(after.id)
+        try:
+            if role not in after.roles:
+                await db.execute("DELETE FROM muted WHERE guild = ? and name = ?", (guildid,memberid))
+                await db.commit()
+                await db.close()
+        except:
+            pass
 class warnings():
     async def warn(ctx, member, dir, reason=None):
         os.chdir(dir)
